Discovery - Evo Python SDK

GitHub source

## evo.discovery.client.DiscoveryAPIClient

Simple client for interacting with the Discovery API.

### __init__

    __init__(connector: APIConnector) -> None

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`connector` | `APIConnector` | The API connector to use for making requests. | required

### list_organizations `async`

    list_organizations(service_codes: Sequence[str] = ('evo',)) -> list[Organization]

Get organizations with access to the specified services.

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`service_codes` | `Sequence[str]` | The service codes to use in the query. | `('evo',)`

#### Keyboard Shortcuts

Keys | Action
--- | ---
`?` | Open this help
`n` | Next page
`p` | Previous page
`s` | Search